Format values as datetimes.
GT.fmt_datetime(
columns=None,
rows=None,
date_style="iso",
time_style="iso",
format_str=None,
sep=" ",
pattern="{x}",
locale=None
)
Format input values to datetime values using one of 17 preset date styles and one of 5 preset time styles. Input can be in the form of datetime values, or strings in the ISO 8601 forms of YYYY-MM-DD HH:MM:SS or YYYY-MM-DD.
Parameters
columns: SelectExpr = None
-
The columns to target. Can either be a single column name or a series of column names provided in a list.
rows: int | list[int] | None = None
-
In conjunction with columns=, we can specify which of their rows should undergo formatting. The default is all rows, resulting in all rows in targeted columns being formatted. Alternatively, we can supply a list of row indices.
date_style: DateStyle = "iso"
-
The date style to use. By default this is the short name "iso" which corresponds to ISO 8601 date formatting. There are 41 date styles in total.
time_style: TimeStyle = "iso"
-
The time style to use. By default this is the short name "iso" which corresponds to how times are formatted within ISO 8601 datetime values. There are 5 time styles in total.
format_str: str | None = None
-
A string that specifies the format of the datetime string. This is a strftime() format string that can be used to format date or datetime input. If format= is provided, the date_style= and time_style= arguments are ignored.
sep: str = " "
-
A string that separates the date and time components of the datetime string. The default is a space character (" "). This is ignored if format= is provided.
pattern: str = "{x}"
-
A formatting pattern that allows for decoration of the formatted value. The formatted value is represented by the {x} (which can be used multiple times, if needed) and all other characters will be interpreted as string literals.
locale: str | None = None
-
An optional locale identifier that can be used for formatting values according the locale’s rules. Examples include
"en" for English (United States) and "fr" for French (France). Only relevant if date_style= or time_style= are provided.
Returns
GT
-
The GT object is returned. This is the same object that the method is called on so that we can facilitate method chaining.
Examples
Let’s use the exibble dataset to create a simple, two-column table (keeping only the date and time columns). With the fmt_datetime() method, we’ll format the date column to display dates formatted with the "month_day_year" date style and the time column to display times formatted with the "h_m_s_p" time style.
from great_tables import GT, exibble
exibble_mini = exibble[["date", "time"]]
(
GT(exibble_mini)
.fmt_datetime(
columns="date",
date_style="month_day_year",
time_style="h_m_s_p"
)
)
| date |
time |
| January 15, 2015 12:00:00 AM |
13:35 |
| February 15, 2015 12:00:00 AM |
14:40 |
| March 15, 2015 12:00:00 AM |
15:45 |
| April 15, 2015 12:00:00 AM |
16:50 |
| May 15, 2015 12:00:00 AM |
17:55 |
| June 15, 2015 12:00:00 AM |
|
|
19:10 |
| August 15, 2015 12:00:00 AM |
20:20 |