md()

Interpret input text as Markdown-formatted text.

Usage

md(text)

Markdown can be used in certain places (e.g., source notes, table title/subtitle, etc.) and we can expect it to render to HTML. There is also the html() helper function that allows you to use raw HTML text.

Parameters

text: str
The text that is understood to contain Markdown formatting.

Examples

See GT.tab_header().