style.fill
A style specification for the background fill of targeted cells.
Usage
style.fill()The style.fill() class is to be used with the tab_style() method, which itself allows for the setting of custom styles to one or more cells. Specifically, the call to style.fill() should be bound to the styles argument of tab_style().
Parameters
color: str | ColumnExpr- The color to use for the cell background fill. This can be any valid CSS color value, such as a hex code, a named color, or an RGB value.
Returns
CellStyleFill-
A CellStyleFill object, which is used for a
stylesargument if specifying a cell fill value.
Examples
See GT.tab_style().