from great_tables import vals
vals.fmt_roman([3, 5])['III', 'V']
Format values as Roman numerals.
Usage
With numeric values we can transform those to Roman numerals, rounding values as necessary.
x: XA list of values to be formatted.
case: str = "upper"Should Roman numerals should be rendered as uppercase ("upper") or lowercase ("lower") letters? By default, this is set to "upper".
pattern: str = "{x}"{x} (which can be used multiple times, if needed) and all other characters will be interpreted as string literals.
list[str]